#
# spec file for package rpmlint-mini
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# This works regardless of the primary python3 flavor. The stdlib.txt and
# install section depend on the python 3.11 layout.
%define python_flavor python311
%define my_python %{expand:%{__%{python_flavor}}}

Name:           rpmlint-mini
Version:        %(rpm -q rpmlint --qf '%%{VERSION}')
Release:        15.89
Summary:        RPM file correctness checker
License:        GPL-2.0-or-later
URL:            https://github.com/rpm-software-management/rpmlint
Source0:        desktop-file-utils-0.26.tar.xz
Source1:        stdlib.txt
Source2:        rpmlint.wrapper
Source3:        rpmlint-mini.rpmlintrc

# PATCH-FEATURE-OPENSUSE desktop-file-utils-suse-keys.patch vuntz@opensuse.org -- Handle SUSE-specific keys in validator. This is not strictly necessary, since they are prefixed with X-, but we can verify that the value has the right type.
Patch0:         desktop-file-utils-suse-keys.patch
# PATCH-FIX-UPSTREAM -- SingleMainWindow is present in xdg-specs 1.5 and can be used by both GNOME and KDE
Patch2:         0001-validate-support-SingleMainWindow-key-from-1.5.patch
Patch3:         0002-validate-Support-version-1.5.patch

# need to fetch the file from there
BuildRequires:  checkbashisms
# the main package rpmlint's python3 runtime requirements do not necessarily match our target flavor
BuildRequires:  %{python_flavor}-base
BuildRequires:  %{python_flavor}-packaging
BuildRequires:  %{python_flavor}-pybeam
BuildRequires:  %{python_flavor}-pyenchant
BuildRequires:  %{python_flavor}-python-magic
BuildRequires:  %{python_flavor}-pyxdg
BuildRequires:  %{python_flavor}-rpm
BuildRequires:  %{python_flavor}-tomli
BuildRequires:  %{python_flavor}-tomli-w
BuildRequires:  %{python_flavor}-xml
BuildRequires:  %{python_flavor}-zstandard
BuildRequires:  dash
BuildRequires:  glib2-devel
BuildRequires:  glib2-devel-static
BuildRequires:  libedit-devel
BuildRequires:  libtool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  rpmlint >= 2
#!BuildIgnore:  rpmlint-mini
Requires:       cpio
Requires:       polkit-default-privs

%description
rpmlint is a tool to check common errors on RPM packages. Binary and
source packages can be checked.

%prep
%autosetup -p1 -n desktop-file-utils-0.26

%build
%meson
%meson_build

%install
# Check that rpmlint works at all, with the primary flavor
set +e
%{_bindir}/rpmlint -i rpmlint
test $? -gt 0 -a $? -lt 60 && exit 1
set -e
# Check that we have all required python modules in the target flavor
for p in $(rpm -q --requires rpmlint | grep '^python3-'); do
  rpm -q --whatprovides ${p/python3-/%{python_flavor}-}
done
# Build a virtual env
%my_python -m venv %{buildroot}/opt/testing --without-pip --copies
# We don't need activation
rm %{buildroot}/opt/testing/bin/activate*
# We need these available
cp -a %{_vpath_builddir}/src/desktop-file-validate %{buildroot}/opt/testing/bin
cp -a %{_bindir}/dash %{_bindir}/checkbashisms %{buildroot}/opt/testing/bin
cp -a %{_libdir}/libedit.so.0* %{buildroot}/opt/testing/lib
# Install config files
install -d -m 755 %{buildroot}/opt/testing/share
cp -a %{_sysconfdir}/xdg/rpmlint %{buildroot}/opt/testing/share
# Override configs are selectively taken from rpmlint-strict
rm -f %{buildroot}/opt/testing/share/rpmlint/*.override.toml
# Python standard library, rpmlint dependencies, and the interpreter
pushd %{_libdir}/python%{python_version}
for file in $(cat %{SOURCE1}); do
  exp=$(ls -1 $file)
  install -D -m 644 $exp %{buildroot}/opt/testing/lib/python%{python_version}/$exp
done
popd
ldd %{python_sitearch}/rpm/*.so | while read L T R A
do
# skip libc/libm, they must match the system ld.so (which we cannot replace)
case $L in lib[cm].*) continue;; esac
cp '-aLt%{buildroot}/opt/testing/lib' "${R}" || # is it a virtual library?
! <"${R}" || # it is a real library and still could not be copied
false # this is necessary to really fail
done
cp -a %{python_sitearch}/{rpm,zstandard}* \
%{buildroot}/opt/testing/lib/python%{python_version}/site-packages
cp -a %{python_sitelib} %{buildroot}/opt/testing/lib/python%{python_version}
cp -a %{python3_sitelib}/rpmlint* %{buildroot}/opt/testing/lib/python%{python_version}
cp -a %{_libdir}/libpython%{python_version}*.so.* %{buildroot}/opt/testing/lib
cp -a %{_libdir}/libexpat*.so.* %{buildroot}/opt/testing/lib
cp -a %{_libdir}/libmpdec*.so.* %{buildroot}/opt/testing/lib || echo "Skipping libmpdec.so"
pushd %{buildroot}/opt/testing/lib/python%{python_version}/
rm -r site-packages/meson*
for f in $(find -name \*.py | sort) ; do
  PYTHONOPTIMIZE=1 %{my_python} -O -m compileall -b $f
  rm $f
done
popd
find %{buildroot}/opt/testing/ -name __pycache__  -exec rm -rf {} +
# Change the script-interpreter line to use our custom python venv in /opt/testing
sed -e '1s,#!.*python.*,#!/opt/testing/bin/python3,' %{_bindir}/rpmlint > %{buildroot}/opt/testing/bin/rpmlint.real

chmod a+x %{buildroot}/opt/testing/bin/rpmlint.real
rm -rf %{buildroot}/{usr,etc}
install -m 755 -D %{SOURCE2} %{buildroot}/opt/testing/bin/rpmlint
# We don't want requirements of libraries, or the odd shebang
%define __requires_exclude (^lib.*|python3)$
# We don't want to provide any libraries, or Python modules we ship
%define __provides_exclude ^(lib|python)

%check
# check rpmlint-mini with the custom flavor
%meson_test
sed -e 's|/opt|%{buildroot}/opt|' -e 's|exec|%my_python|' %{buildroot}/opt/testing/bin/rpmlint > myrpmlint
chmod +x myrpmlint
set +e
sh -x myrpmlint -i rpmlint
test $? -gt 0 -a $? -lt 60 && exit 1
set -e

%files
/opt/testing
%license COPYING

%changelog
* Thu Feb  1 2024 Andreas Schwab <schwab@suse.de>
- Don't include copy of libm
* Fri Oct 13 2023 Ben Greiner <code@bnavigator.de>
- Bump to python311
- Clarify script interpreter line
- update rpmlintrc
- Don't install buildtime requirement mesonbuild into the custom
  runtime environment
* Wed Oct 11 2023 Daniel Garcia <daniel.garcia@suse.com>
- Make rpmlint shebang replacement independent on the shebang in the
  rpmlint script.
* Mon Jul 17 2023 Ana Guerrero <ana.guerrero@suse.com>
- Add BuildRequires on python-packaging to fix build.
* Tue May 23 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add patches to avoid bogus errors in post-build checks:
  * 0001-validate-support-SingleMainWindow-key-from-1.5.patch
  * 0002-validate-Support-version-1.5.patch
  * desktop-file-utils-suse-keys.patch
- Update desktop-file-utils source to 0.26:
  * Support for Autotools removed in the next release.
  * update-desktop-database
    + Fix erroneous installation as "desktop-file-update"
    when using the Meson build system
- Update to version 0.25:
  * common
    + Add Meson build system
  * desktop-file-validate
    + Allow desktop file spec version 1.4.
    + Make it possible to deprecate keys starting with "X-".
    + Add the "Implements" field from spec version 1.2.
    + Add the "PrefersNonDefaultGPU" key and deprecate "X-KDE-RunOnDiscreteGpu".
    + Set locale for correct output message encoding.
    + Add coloured output support.
    + Fix parsing of escaped double quote in quoted strings.
    + Add GNOME Flashback, GNOME Classic desktops.
* Wed Mar 29 2023 Martin Liška <mliska@suse.cz>
- Depend on python-magic Python package.
* Thu Feb  2 2023 Andreas Schwab <schwab@suse.de>
- Don't include copy of libc
* Mon Sep 12 2022 Martin Liška <mliska@suse.cz>
- Remove extra %%make_build arguments.
* Mon Sep  5 2022 Christopher Yeleighton <giecrilj@stegny.2a.pl>
- Copy libraries required by _rpm.cpython to the testing root (boo#1203093).
* Mon Jul 25 2022 Martin Liška <mliska@suse.cz>
- Replace toml library with tomli.
* Mon May  9 2022 Ben Greiner <code@bnavigator.de>
- Use python310 flavor explicitly, irrespective of the primary
  python3 flavor du jour.
* Sat May  7 2022 Ben Greiner <code@bnavigator.de>
- Migration of primary Python interpreter to 3.10
  * update stdlib.txt: encoding, importlib, lib-dynload,
    dataclasses, ast
  * Remove deprecated stdlib distutils from the venv
    (not used by rpmlint)
  * Do not install+delete pip in the venv
- Update URL
- Explicit BuildRequires: python-rpm-macros -- sitelib macros
  are used.
* Sat Mar  5 2022 Martin Liška <mliska@suse.cz>
- Enable --time-report.
* Wed Feb  2 2022 Ben Greiner <code@bnavigator.de>
- include typing.py into the installed stdlib because
  python-zstandard is typed now.
* Tue Feb  1 2022 Martin Liška <mliska@suse.cz>
- Support updated python-zstandard package.
* Mon Jan 10 2022 Martin Liška <mliska@suse.cz>
- Fix spec file: install zstdandard package properly.
* Mon Jan 10 2022 Martin Liška <mliska@suse.cz>
- Add rpmlintrc filter for pycparser Python package.
* Mon Sep  6 2021 Martin Liška <mliska@suse.cz>
- Install %%{_libdir}/libmpdec*.so.* to venv as it can be used
  by _pydecimal.py python module.
* Mon Aug 30 2021 Martin Liška <mliska@suse.cz>
- Share Version with rpmlint package.
* Fri Aug  6 2021 Martin Liška <mliska@suse.cz>
- Add run-time requirement for polkit-default-privs.
* Thu Aug  5 2021 Martin Liška <mliska@suse.cz>
- Rely on rpmlint auto-loading support for rpmlintrc files.
* Thu Aug  5 2021 Martin Liška <mliska@suse.cz>
- Do not copy .override. config files.
* Tue Aug  3 2021 Martin Liška <mliska@suse.cz>
- Properly redirect stdout to /dev/null.
* Mon Jul 26 2021 Steve Kowalik <steven.kowalik@suse.com>
- Try two for supporting multiple rpmlintrc, since shell for loops
  always loop, even if the files don't exist.
* Fri Jul 23 2021 Steve Kowalik <steven.kowalik@suse.com>
- Support multiple rpmlintrc files correctly.
* Thu Jul 22 2021 Martin Liška <mliska@suse.cz>
- Use --mini-mode when calling rpmlint from rpmlint-mini package.
* Mon Jul 12 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to require rpmlint >= 2.
  * Due to rpmlint now being a proper Python package, build a virtual
    environment, and copy all Python requirements into it.
  * Replace rpmlint-deps.txt with stdlib.txt, as we need to provide the
    Python standard library directly.
  * Lightly rewrite rpmlint.wrapper to support the new world order.
- Drop the config snippets, they are not required with rpmlint 2.
- Renumber Source numbers.
- Filter some more warnings in rpmlint-mini.rpmlintrc.
* Thu Mar 25 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- apply workaround for situations in which regular rpmlint is invoked when
  building rpmlint-mini. Regular rpmlint does not implicitly add rpmlintrc
  files, causing fatal badness to occur when building rpmlint-mini. Therefore
  explicitly copy our rpmlintrc to a location that is processed by regular
  rpmlint, too.
* Thu Sep 10 2020 matthias.gerstner@suse.com
- Update of rpmlint-security-whitelistings:
  * world-writable-whitelist: fix mixed tabs/whitespace
  * device-files-whitelist: fix mode of named: urandom dev file
* Wed Aug 12 2020 matthias.gerstner@suse.com
- seucirty-whitelistings: update to version master:
  * Introduce new metadata based whitelistings for device files and world-writable files
* Tue Jul 28 2020 matthias.gerstner@suse.com
- Update to version master:
  * opa-ff: add wildcard whitelisting (bsc#1174464)
* Mon Jul 13 2020 matthias.gerstner@suse.com
- Update to version master:
  * whitelist ppc64-diag cron job (bsc#1173044)
* Fri Jun 12 2020 matthias.gerstner@suse.com
- Update to version master:
  * cron-whitelist: adjust bug reference to point to real bug, not the sr#
    (opa-ff bsc#1172859)
* Wed Jun 10 2020 matthias.gerstner@suse.com
- Update to version master:
  * cron-whitelist: follow-up digest for opa-ff
* Thu Apr  9 2020 matthias.gerstner@suse.com
- Update of security-whitelistings tarball:
  * cron-whitelist: follow-up whitelisting for nextcloud (bsc#1168964)
  * clarify audit sections
* Fri Mar 20 2020 Dirk Mueller <dmueller@suse.com>
- fix typo in codec setting (bsc#1165110)
* Thu Mar  5 2020 matthias.gerstner@suse.com
- Update to version master:
  * cron-whitelist: remove bad duplicate entry for texlive-filesystem
  * verify.py: catch duplicate dictionary entries in JSON
* Wed Mar  4 2020 matthias.gerstner@suse.com
- Update to version master:
  * cron-whitelist: add entry for sarg (bsc#1150554)
* Mon Mar  2 2020 matthias.gerstner@suse.com
  rpmlint-security-whitelistings:
  Update to version master:
  * cron-whitelist: add opa-ff (bsc#1162255)
  * cron-whitelist: add matomo (bsc#1150548)
  * cron-whitelist: preliminary wildcard whitelisting for the notorious texlive-filesystem (bsc#1150556)
  * cron-whitelist: whitelist new nextcloud cron job
  * first round of whitelisting of safe cron jobs (bsc#1150175)
* Mon Dec 16 2019 Johannes Segitz <jsegitz@suse.de>
- Extended rpmlint-mini.config to include the config file provided
  by rpmlint-Factory-strict
* Sat Dec 14 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use wildcard for Python ABI tag when copying files, fixes build
  with Python 3.8 (the has been irrelevant since 3.4 and has been
  removed with 3.8).
* Tue Dec 10 2019 matthias.gerstner@suse.com
- Update to version master:
  * add _servicedata which I forgot previously when adding the new
    rpmlnit-security-whitelistings.
* Fri Dec  6 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Sort file list to build .pyc files reproducibly
* Tue Nov 19 2019 matthias.gerstner@suse.com
- include new rpmlint-security-whitelistings. This will in the future house
  a whitelist for cron jobs (bsc#1150175), among possible additional future
  whitelists.
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid bash-specific constructs in build recipe
* Tue Aug 13 2019 Dirk Mueller <dmueller@suse.com>
- update desktop-file-utils to 0.24 release
  + Allow desktop file spec version 1.2.
  + Add Budgie, Deepin, Enlightenment and Pantheon to list of
    registered desktop environments.
  + Sort output lines internally to conserve reproducibility.
  + Use pledge(2) on OpenBSD to limit capabilities.
  + Fix missing ; when appending to a list not ending with one.
  + Add font as valid media type.
  + Fix broken emacs blocking compile.
* Mon Feb 25 2019 matthias.gerstner@suse.com
- Add dependency to new polkit-whitelisting subpackage of polkit-default-privs
  and embed the JSON file for polkit rules.d whitelistings. This is necessary
  for the upcoming implementation of a new rpmlint-check to cover files in
  /etc/polkit-1/rules.d and /usr/share/polkit-1/rules.d (bsc#1125314).
- For this we will also need the json python module, since the new whitelist
  will be in the JSON format.
* Wed Dec 26 2018 matwey.kornilov@gmail.com
- Add imp and pickle to rpmlint-deps.txt
  they are required by python-construct=2.9
  which is required by python-pybeam=0.5
* Sun Jul 15 2018 jslaby@suse.com
- python is 3.7, so update rpmlint-deps.txt (use ? instead of minor
  version)
* Mon Dec  4 2017 dimstar@opensuse.org
- rpmlint-deps.txt: Follow changes from rpm and copy _rpm*.so
  instead of _rpm.so (the name is newly extended with .cpython).
* Wed Nov  1 2017 dmueller@suse.com
- set locale to C.utf8 to avoid non-ascii warnings
* Tue Oct 24 2017 jengelh@inai.de
- Update descriptions. Use better-performing find invocations.
* Mon Oct 16 2017 dmueller@suse.com
- don't include a copy of libmagic (bsc#976406)
* Thu Oct 12 2017 stefan.bruens@rwth-aachen.de
- Use wildcard for sysconfigdata architecture in rpmlint-deps.txt
- Use wildcard for abi in rpmlint-deps.txt, e.g. armv7hl is gnueabihf
* Tue Oct 10 2017 dmueller@suse.com
- also import ElementTree
- include pybeam also for lib64 architectures
* Thu Sep 28 2017 dmueller@suse.com
- rebuild against rpmlint 1.10
  drops: rpmlint-deps.patch
- Switch to Python 3.x
* Fri May 26 2017 matwey.kornilov@gmail.com
- Add rpmlint-deps.patch:
  Revert 'Adapt rpmlint-deps.txt for python-construct >= 2.8'
  for Leap 42.x
* Wed Feb  1 2017 meissner@suse.com
- buildignore ourselves to allow better bootstrapping.
* Wed Jan 18 2017 matwey.kornilov@gmail.com
- Adapt rpmlint-deps.txt for python-construct >= 2.8
* Fri Dec  9 2016 dimstar@opensuse.org
- Configure appdata_checker: pass --nonet in plus: as OBS has no
  internet access, every appdata file containing screenshots would
  be marked as 'failed' otherwise.
* Fri Oct 28 2016 dmueller@suse.com
- update desktop-file-utils to 0.23:
  + Accept version 1.1 desktop files.
  + Add Cinnamon, EDE and LXQt to the list of registered desktop
    environments (fdo#73497, fdo#56353, fdo#79561).
  + Allow multipart/related MIME type; it's used for MHTML
    (fdo#93376).
  + Ensure DBusActivatable filenames conform to reverse-DNS
    notation (fdo#66904).
  + Downgrade trailing semicolons to optional (fdo#76902).
  + Fix buffer over-read (fdo#94303).
* Wed Apr 20 2016 werner@suse.de
- Also copy magic and magic.mgc to /opt/testing to have the
  correct magic files for the used libmagic around.
  Use the environment variable MAGIC to hel the wrapper to
  to find the magic file for its libmagic (boo#976406)
* Mon Feb 22 2016 dmueller@suse.com
- raise version to 1.8
* Mon Apr 20 2015 lnussel@suse.de
- add lib-dynload/unicodedata.so required by rpmlint 1.6
* Sat Apr 26 2014 matwey.kornilov@gmail.com
- package dependencies of ErlangCheck.py:
  - python-pybeam
  - python-construct
  - python-six
  note, that ErlangCheck.py is not enabled by default
* Thu Oct  3 2013 dmueller@suse.com
- repackage libedit0 dependency of dash
* Wed Oct  2 2013 lnussel@suse.de
- dash is in /usr/bin now
* Tue Sep 24 2013 dmueller@suse.com
- no longer install rpmgroups.config
* Mon Sep  2 2013 dmueller@suse.com
- update to desktop-file-validate 0.22:
  - add DBusActivatable key to allowed keys
  - warn about OnlyShowIn in Action groups
  - allow validating multiple desktop files
  - improve help output
  - update man page
* Fri Jun 28 2013 dmueller@suse.com
- update to desktop-file-validate 0.21:
  - update to current version of menu specification (Vincent):
  - only print hint if no main category is present, not an error
  - make Science a main category
  - add new registered categories: Adult, Feed, Humanities, Maps,
    Shooter, Spirituality, XFCE
  - update related categories
  - add TDE to list of registered OnlyShowIn
  - accept and validate GNOME3/GSettings for AutostartCondition (Vincent)
  - output hint if more than one main category is present (Vincent)
  - output hint about suggested related categories (Vincent)
* Wed Jun 26 2013 dmueller@suse.com
- fix build against python 2.7.5
* Wed Jan  2 2013 dmueller@suse.com
- bump version to 1.4
* Sun Oct 28 2012 coolo@suse.com
- fix build by passing rpmlint :)
* Sun Oct 28 2012 coolo@suse.com
- let it require cpio - the same as with rpmlint
* Wed Sep 12 2012 dmueller@suse.com
- update to desktop-file-validate 0.20 (bnc#779850):
  - add MATE and Razor to list of registered environments (Vincent)
  - validate Desktop Actions (Giovanni Campagna, Vincent)
* Fri Feb 24 2012 giecrilj@stegny.2a.pl
- add documentation
* Wed Dec 21 2011 dmueller@suse.de
- update desktop-file-validate to 0.19:
  - add Unity to list of registered environments
  - deal with various zz-application/zz-winassoc-XXX mime types
  - mark all zz-application/* MIME types as aliases
  - add support for updated Keywords key
  - accept x-scheme-handler/* mime types
* Tue Nov 29 2011 lnussel@suse.de
- install licenses.config
* Mon Oct 24 2011 dmueller@suse.de
- add the new abuild build path to the search dir list
* Thu Aug 18 2011 dmueller@suse.de
- bump version to 1.3 (matching rpmlint update)
* Fri Jul  8 2011 dmueller@novell.com
- fix magic detection after the file update to 5.07
* Fri May 20 2011 dmueller@suse.de
- bump version to 1.2 (matching rpmlint update)
* Wed May 11 2011 lnussel@suse.de
- include pie.config
* Tue Apr 19 2011 lnussel@suse.de
- allow adding configs via RPMLINT_MINI_CONFIG
* Mon Apr 18 2011 lnussel@suse.de
- add missing deps
* Fri Apr 15 2011 dmueller@suse.de
- bump version to 1.1 (matching rpmlint update)
* Thu Mar 10 2011 lnussel@suse.de
- rlwarn was renamed to warn
* Sun Nov 21 2010 coolo@novell.com
- fix lib requirements of libglib
* Thu Nov 11 2010 dmueller@suse.de
- bump version to 1.0 (match rpmlint update)
* Mon Sep 27 2010 dmueller@suse.de
- bump version to 0.99 (match rpmlint update)
- buildrequire glib2-devel-static (new package split)
* Mon Sep 20 2010 dmueller@suse.de
- fix build against autoconf 2.67
  + update to desktop-file-utils 0.17:
  - accept chemical/* mime types as valid types
  - make icon names with an extension for Icon key a non-fatal
    error
  - check that a main category is included in the Categories
  - check that categories required by another one are present
  - do not always show warnings about KDE specific uses
  - check that the Comment does not look like the Name and the
    GenericName
  - display error about multiple keys with the same name earlier
  - improve MIME type check to make sure that the MIME types are
    valid
  - add LXDE in the list of registered OnlyShowIn values
  - add "warning" to error strings to make them easily greppable
  - handle AutostartCondition key, as proposed for the autostart
    specification and used in GNOME
  - accept empty Categories key as valid
  - make new errors non-fatal to give some time to maintainers to
    fix their .desktop file after a release of desktop-file-utils
  - plug leak
  - code cleanups
* Sun Sep 12 2010 dmueller@suse.de
- fix build against python 2.7
* Tue Aug  3 2010 dmueller@suse.de
- add string_escape to dependencies, needed by checkbashisms
* Tue Jul 20 2010 guido+opensuse.org@berhoerster.name
- include dash and checkbashisms needed by BashismsCheck
* Mon Mar 29 2010 dmueller@suse.de
- update dependency list for rpmlint 0.95 / rpm 4.8.0
* Fri Feb 26 2010 lnussel@suse.de
- fix polkit check
* Thu Feb 25 2010 lnussel@suse.de
- configure CheckPolkitPrivs
* Thu Jan 21 2010 lnussel@suse.de
- remove error prone package-rpmlintrc.diff. Instead have rpmlint
  execute a file via standard means which in turn reads custom
  configs
* Wed Jan 13 2010 lnussel@suse.de
- add rpmgroups.config
* Mon Sep 28 2009 lnussel@suse.de
- include python-magic to fix e.g. the 'no-binary' check (bnc#539042)
* Wed Sep 16 2009 mrueckert@suse.de
- fix build with rpmlint 0.90
* Mon Aug 24 2009 lnussel@suse.de
- fix build with rpmlint 0.87
* Fri Jan 23 2009 lnussel@suse.de
- include StringIO.pyo, needed by xml module used by the dbus policy
  check to print useful errors
* Thu Dec 11 2008 lnussel@suse.de
- add python-xml parts needed for PolicyKit checks
* Sat Sep 27 2008 adrian@suse.de
- fix dependencies of python again (bnc#430381)
- add self check to avoid breakage in future
* Mon Sep  8 2008 ro@suse.de
- next try to get a working rpmlint again
* Mon Sep  8 2008 dmueller@suse.de
- fix build again
* Thu Aug  7 2008 dmueller@suse.de
- fix build for python 2.6
* Thu Jul 24 2008 dmueller@suse.de
- support even OBS style of building
* Mon Jun 30 2008 schwab@suse.de
- Fix syntax error.
* Fri Jun 27 2008 dmueller@suse.de
- ignore warnings in the test package
* Mon Mar 10 2008 dmueller@suse.de
- update desktop-file-validate to 0.14
  * for changelog, see desktop-file-utils package
* Wed Feb 13 2008 dmueller@suse.de
- update to (also) build rpmlint 0.82
* Thu Nov 22 2007 dmueller@suse.de
- add missing utf8 module (#343642)
* Mon Oct 29 2007 dmueller@suse.de
- update to (also) build rpmlint 0.81
- update desktop-file-validate to 0.14
* Thu Jun 21 2007 dmueller@suse.de
- refresh patches
* Thu Jun  7 2007 dmueller@suse.de
- update desktop-file-validate to 0.13
- fix build for lib64 archs
* Wed Jun  6 2007 dmueller@suse.de
- add static copy of desktop-file-validate to fix
  the rpmlint check for desktop files
* Mon Jun  4 2007 dmueller@suse.de
- remove source files to reduce size
- read $RPM_SOURCE_DIR/%%{name}-%%{version}-rpmlintrc as well
* Thu May 24 2007 dmueller@suse.de
- read $RPM_SOURCE_DIR/rpmlintrc as well to allow
  package specific overrides
* Tue May 15 2007 dmueller@suse.de
- Initial package
